==> qtubuntu_0.52+13.10.20131016.orig.tar.gz: qtubuntu-0.52+13.10.20131016/src/platforms/ubuntu/ubuntumir/ubuntumirserver/main.cc <==
// This file is part of QtUbuntu, a set of Qt components for Ubuntu.
// Copyright © 2013 Canonical Ltd.
//
// This program is free software: you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 3, as published by
// the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranties of MERCHANTABILITY,
// SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#include <qpa/qplatformintegrationplugin.h>
#include "ubuntumircommon/integration.h"

QT_BEGIN_NAMESPACE

class QUbuntuMirServerIntegrationPlugin : public QPlatformIntegrationPlugin {
  Q_OBJECT
  Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QPA.QPlatformIntegrationFactoryInterface.5.1"
                    FILE "ubuntumirserver.json")

 public:
  QStringList keys() const;
  QPlatformIntegration* create(const QString&, const QStringList&);
};

QStringList QUbuntuMirServerIntegrationPlugin::keys() const {
  QStringList list;
  list << "ubuntumirserver";
  return list;
}

QPlatformIntegration* QUbuntuMirServerIntegrationPlugin::create(
    const QString& system, const QStringList& paramList) {
  Q_UNUSED(paramList);
  if (system.toLower() == "ubuntumirserver")
    return new QUbuntuMirIntegration();
  return 0;
}

QT_END_NAMESPACE

#include "main.moc"

==> qtubuntu_0.54+14.04.20140402.orig.tar.gz: qtubuntu-0.54+14.04.20140402/src/platforms/ubuntu/ubuntumir/ubuntumirserver/main.cc <==
// This file is part of QtUbuntu, a set of Qt components for Ubuntu.
// Copyright © 2013 Canonical Ltd.
//
// This program is free software: you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 3, as published by
// the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranties of MERCHANTABILITY,
// SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#include <qpa/qplatformintegrationplugin.h>
#include "ubuntumircommon/integration.h"

QT_BEGIN_NAMESPACE

class QUbuntuMirServerIntegrationPlugin : public QPlatformIntegrationPlugin {
  Q_OBJECT
  Q_PLUGIN_METADATA(IID QPlatformIntegrationFactoryInterface_iid
                    FILE "ubuntumirserver.json")

 public:
  QStringList keys() const;
  QPlatformIntegration* create(const QString&, const QStringList&);
};

QStringList QUbuntuMirServerIntegrationPlugin::keys() const {
  QStringList list;
  list << "ubuntumirserver";
  return list;
}

QPlatformIntegration* QUbuntuMirServerIntegrationPlugin::create(
    const QString& system, const QStringList& paramList) {
  Q_UNUSED(paramList);
  if (system.toLower() == "ubuntumirserver")
    return new QUbuntuMirIntegration();
  return 0;
}

QT_END_NAMESPACE

#include "main.moc"
